@@ -5,11 +5,11 @@ import bokeh.colors
 import numpy as np
 import os
 import glob
+from forest import _profile as profile
 from forest import (
         satellite,
         screen,
         tools,
-        profile,
         series,
         data,
         load,
